##########################################################################
# test_task_msuvbinflag.py
#
# Copyright (C) 2018
# Associated Universities, Inc. Washington DC, USA.
#
# This script is free software; you can redistribute it and/or modify it
# under the terms of the GNU Library General Public License as published by
# the Free Software Foundation; either version 2 of the License, or (at your
# option) any later version.
#
# This library is distributed in the hope that it will be useful, but WITHOUT
# ANY WARRANTY; without even the implied warranty of MERCHANTABILITY or
# FITNESS FOR A PARTICULAR PURPOSE.  See the GNU Library General Public
# License for more details.
#
# [Add the link to the JIRA ticket here once it exists]
#
# Based on the requirements listed in plone found here:
# https://casadocs.readthedocs.io/en/stable/api/tt/casatasks.manipulation.msuvbinflag.html
#
#
##########################################################################
import sys
import os
import numpy as np
import unittest
import shutil
import casatools
from casatasks import flagdata
from casatasks import msuvbinflag

tb = casatools.table()


ctsys_resolve = casatools.ctsys.resolve

## DATA ## 

datapath = ctsys_resolve('unittest/msuvbinflag')


class test_msuvbinflag(unittest.TestCase):

    ms = 'SNR_ForFlagging_Binned.ms'

    def setUp(self):
         if(not os.path.exists(self.ms)):
             os.system('cp -RH '+datapath+'/'+self.ms+' .')

    def tearDown(self):
        shutil.rmtree(self.ms)


    def test_radian_method(self):
        res = flagdata(vis=self.ms, mode='summary')
        msuvbinflag(binnedvis=self.ms, method='radial',  sigma=3.0)
        res = flagdata(vis=self.ms, mode='summary')
        self.assertEqual(res['flagged'], 16671)

    def test_regionalMean_method(self):
        res = flagdata(vis=self.ms, mode='summary')
        self.assertEqual(res['flagged'], 16671)
        msuvbinflag(binnedvis=self.ms,  method='regionalMean', sizeRegion=20, sigma=5, ignorPoint=True)
        res = flagdata(vis=self.ms, mode='summary')
        self.assertEqual(res['flagged'], 15223)


    def test_median_method(self):
        res = flagdata(vis=self.ms, mode='summary')
        self.assertEqual(res['flagged'], 15223)
        msuvbinflag(binnedvis=self.ms, method='median', sigma=5)
        res = flagdata(vis=self.ms, mode='summary')
        self.assertEqual(res['flagged'], 14324)

    def test_gradient_method(self):
        res = flagdata(vis=self.ms, mode='summary')
        self.assertEqual(res['flagged'], 14324)
        msuvbinflag(binnedvis=self.ms, method='gradient', radius=1.0, sigma=0.3)
        res = flagdata(vis=self.ms, mode='summary')
        self.assertEqual(res['flagged'], 13324)


if __name__ == '__main__':
    unittest.main()
        